# Finka

Finka는 각종 financial data수집을 도와주는 툴 입니다.
아래의 데이터를 편하게 수집하여 Pandas DataFrame 으로 사용할 수 있습니다.

1. DART 전자공시시스템 Open API

# DART 전자공시 시스템 Open API

## 계정 등록 & Open API 인증키 생성

1. [DART 계정 신청](https://dart.fss.or.kr/dsag002/insertForm.do)
2. [인증키 신청 페이지](https://opendart.fss.or.kr/uss/umt/EgovMberInsertView.do)에 들어가서 먼저 API Key 를 받아야 합니다.

위의 계정신청 이후, 인증키 신청후, "오픈API 이용현황"에 들어가면 API Key 가 존재합니다.

![](images/dart-account.png)